@@ -21,6 +21,8 @@ pub struct Commit<'a> {
     description: &'a str,
     body: Option<&'a str>,
     breaking: bool,
+    #[cfg_attr(feature = "serde", serde(skip))]
+    breaking_description: Option<&'a str>,
     footers: Vec<Footer<'a>>,
 }
 
@@ -36,10 +38,12 @@ impl<'a> Commit<'a> {
         let (ty, scope, breaking, description, body, footers) =
             parse::<VerboseError<&'a str>>(string).map_err(|err| Error::with_nom(string, err))?;
 
-        let breaking = breaking.is_some()
-            || footers
-                .iter()
-                .any(|(k, _, _)| k == &BREAKING_PHRASE || k == &BREAKING_ARROW);
+        let breaking_description = footers
+            .iter()
+            .filter_map(|(k, _, v)| (k == &BREAKING_PHRASE || k == &BREAKING_ARROW).then(|| *v))
+            .next()
+            .or_else(|| breaking.then(|| description));
+        let breaking = breaking_description.is_some();
         let footers: Result<Vec<_>, Error> = footers
             .into_iter()
             .map(|(k, s, v)| Ok(Footer::new(FooterToken::new_unchecked(k), s.parse()?, v)))
@@ -52,6 +56,7 @@ impl<'a> Commit<'a> {
             description,
             body,
             breaking,
+            breaking_description,
             footers,
         })
     }
@@ -95,6 +100,14 @@ impl<'a> Commit<'a> {
         self.breaking
     }
 
+    /// Explanation for the breaking change.
+    ///
+    /// Note: if no `BREAKING CHANGE` footer is provided, the `description` is expected to describe
+    /// the breaking change.
+    pub fn breaking_description(&self) -> Option<&str> {
+        self.breaking_description
+    }
+
     /// Any footer.
     ///
     /// A footer is similar to a Git trailer, with the exception of not
@@ -291,6 +304,28 @@ impl<'a> Type<'a> {
     }
 }
 
+/// Common commit types
+impl Type<'static> {
+    /// Commit type when introducing new features (correlates with `minor` in semver)
+    pub const FEAT: Type<'static> = Type::new_unchecked("feat");
+    /// Commit type when patching a bug (correlates with `patch` in semver)
+    pub const FIX: Type<'static> = Type::new_unchecked("fix");
+    /// Possible commit type when reverting changes.
+    pub const REVERT: Type<'static> = Type::new_unchecked("revert");
+    /// Possible commit type for changing documentation.
+    pub const DOCS: Type<'static> = Type::new_unchecked("docs");
+    /// Possible commit type for changing code style.
+    pub const STYLE: Type<'static> = Type::new_unchecked("style");
+    /// Possible commit type for refactoring code structure.
+    pub const REFACTOR: Type<'static> = Type::new_unchecked("refactor");
+    /// Possible commit type for performance optimizations.
+    pub const PERF: Type<'static> = Type::new_unchecked("perf");
+    /// Possible commit type for addressing tests.
+    pub const TEST: Type<'static> = Type::new_unchecked("test");
+    /// Possible commit type for other things.
+    pub const CHORE: Type<'static> = Type::new_unchecked("chore");
+}
+
 impl<'a> Scope<'a> {
     /// Parse a `str` into a `Scope`.
     pub fn parse(sep: &'a str) -> Result<Self, Error> {
@@ -338,8 +373,12 @@ mod test {
     #[test]
     fn test_breaking_change() {
         let commit = Commit::parse("feat!: this is a breaking change").unwrap();
-        assert_eq!(crate::FEAT, commit.type_());
+        assert_eq!(Type::FEAT, commit.type_());
         assert!(commit.breaking());
+        assert_eq!(
+            commit.breaking_description(),
+            Some("this is a breaking change")
+        );
 
         let commit = Commit::parse(indoc!(
             "feat: message
@@ -347,12 +386,13 @@ mod test {
             BREAKING CHANGE: breaking change"
         ))
         .unwrap();
-        assert_eq!(crate::FEAT, commit.type_());
+        assert_eq!(Type::FEAT, commit.type_());
         assert_eq!(
             "breaking change",
             &*commit.footers().get(0).unwrap().value()
         );
         assert!(commit.breaking());
+        assert_eq!(commit.breaking_description(), Some("breaking change"));
 
         let commit = Commit::parse(indoc!(
             "fix: message
@@ -360,9 +400,10 @@ mod test {
             BREAKING-CHANGE: it's broken"
         ))
         .unwrap();
-        assert_eq!(crate::FIX, commit.type_());
+        assert_eq!(Type::FIX, commit.type_());
         assert_eq!("it's broken", &*commit.footers().get(0).unwrap().value());
         assert!(commit.breaking());
+        assert_eq!(commit.breaking_description(), Some("it's broken"));
     }
 
     #[test]
@@ -378,7 +419,7 @@ mod test {
 
         let commit = Commit::parse(commit).unwrap();
 
-        assert_eq!(crate::CHORE, commit.type_());
+        assert_eq!(Type::CHORE, commit.type_());
         assert_eq!(None, commit.scope());
         assert_eq!("improve changelog readability", commit.description());
         assert_eq!(
